@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate;
-$Web::Authenticate::VERSION = '0.004';
+$Web::Authenticate::VERSION = '0.005';
 use Mouse;
 use Carp;
 use Web::Authenticate::Cookie::Handler;
@@ -122,8 +122,8 @@ sub login {
     _validate_role_arrayref('authenticators', $params{authenticators}, 'Web::Authenticate::Authenticator::Role');
     _validate_role_arrayref('auth_redirects', $params{auth_redirects}, 'Web::Authenticate::Authenticator::Redirect::Role');
 
-    $params{authenticators} //= [];
-    $params{auth_redirects} //= [];
+    $params{authenticators} ||= [];
+    $params{auth_redirects} ||= [];
 
     my $user = $self->user_storage_handler->load_user(@{$params{login_args}});
 
@@ -178,7 +178,7 @@ sub authenticate {
 
     _validate_role_arrayref('auth_redirects', $params{auth_redirects}, 'Web::Authenticate::Authenticator::Redirect::Role');
 
-    $params{auth_redirects} //= [];
+    $params{auth_redirects} ||= [];
 
     my $is_authenticated = $self->is_authenticated(@_, redirect => 1);
 
@@ -211,7 +211,7 @@ sub is_authenticated {
 
     _validate_role_arrayref('authenticators', $params{authenticators}, 'Web::Authenticate::Authenticator::Role');
 
-    $params{authenticators} //= [];
+    $params{authenticators} ||= [];
 
     my $session = $self->session_handler->get_session;
 
@@ -256,8 +256,8 @@ sub create_user {
     _validate_role_arrayref('username_verifiers', $username_verifiers, 'Web::Authenticate::User::CredentialVerifier::Role');
     _validate_role_arrayref('password_verifiers', $password_verifiers, 'Web::Authenticate::User::CredentialVerifier::Role');
 
-    $username_verifiers //= [];
-    $password_verifiers //= [];
+    $username_verifiers ||= [];
+    $password_verifiers ||= [];
 
     my @failed_username_verifiers;
     for my $verifier (@$username_verifiers) {
@@ -304,7 +304,7 @@ Web::Authenticate - Allows web authentication using cookies and a storage engine
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
