@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate::Session::Storage::Handler::SQL;
-$Web::Authenticate::Session::Storage::Handler::SQL::VERSION = '0.004';
+$Web::Authenticate::Session::Storage::Handler::SQL::VERSION = '0.005';
 use Mouse;
 use Carp;
 use DateTime;
@@ -158,7 +158,7 @@ sub store_session {
     my $session_id_field = $self->session_id_field;
     my $expires_field = $self->expires_field;
 
-    $session_values //= {};
+    $session_values ||= {};
     $session_values->{$user_id_field} = $user->id;
     $session_values->{$session_id_field} = $self->session_id_digest_hex->($session_id);
     $session_values->{$expires_field} = $expires;
@@ -309,7 +309,7 @@ Web::Authenticate::Session::Storage::Handler::SQL - Implementation of Web::Authe
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
