@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate::User::Storage::Handler::SQL;
-$Web::Authenticate::User::Storage::Handler::SQL::VERSION = '0.004';
+$Web::Authenticate::User::Storage::Handler::SQL::VERSION = '0.005';
 use Mouse;
 use Carp;
 use DBIx::Raw;
@@ -129,7 +129,7 @@ sub store_user {
     my $username_field = $self->username_field;
     my $password_field = $self->password_field;
 
-    $user_values //= {};
+    $user_values ||= {};
     $user_values->{$username_field} = $username;
     $user_values->{$password_field} = $self->digest->generate($password);;
 
@@ -180,7 +180,7 @@ Web::Authenticate::User::Storage::Handler::SQL - Implementation of Web::Authenti
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
